# GatewayState

The state of the transaction at the payment gateway. 

## Enum

* `MARKEDFORSUBMISSION` (value: `'MarkedForSubmission'`)

* `SUBMITTED` (value: `'Submitted'`)

* `SETTLED` (value: `'Settled'`)

* `NOTSUBMITTED` (value: `'NotSubmitted'`)

* `FAILEDTOSETTLE` (value: `'FailedToSettle'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


